Optimizing FCP/LCP by caching raw-view module lookups

Would you mind sharing the Firefox and OS version? The 290ms number is almost 3x slower than a 2018 android device, which is a little surprising.

That may explain some of the difference, yeah. In my case, I ran them using live data from Meta:

bin/ember-cli --environment production --proxy https://meta.discourse.org

Yeah, this is a possible improvement. However, we’ll need to be very careful that the layout and/or scrolling doesn’t jump around (e.g. if the user is refreshing the page when they’re already scrolled halfway down). The definition of ‘below the fold’ also varies based on the device/browser/theme.